<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>Köszönet</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>Támogatás</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>Egy többplatformos alkalmazás gyors képernyőképkészítésre.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Egy könnyed és erőteljes alkalmazás Qt-ban.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="108"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="112"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="119"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Csatlakozhat hozzánk, és segíthet nekünk, ha akar. Ez egy meghívás, ha tetszik ez az alkalmazás.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="122"/>
        <source>What you can do?</source>
        <translation>Miben segíthet</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="125"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>A ScreenGrab fordítása</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Make suggestions for next releases</source>
        <translation>Javaslatok a következő kiadásokhoz</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Report bugs and issues</source>
        <translation>Hibák és problémák jelentése</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="130"/>
        <source>Bug tracker</source>
        <translation>Hibakövető</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="140"/>
        <source>Translate:</source>
        <translation>Fordítás:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source> Brazilian Portuguese translation</source>
        <translation> Brazil-portugál fordítás</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source>Marcio Moraes</source>
        <translation>Marcio Moraes</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source> Ukrainian translation</source>
        <translation> Ukrán fordítás</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source>Gennadi Motsyo</source>
        <translation>Gennadi Motsyo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="148"/>
        <source> Spanish translation</source>
        <translation> Spanyol fordítás</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source>Burjans L García D</source>
        <translation>Burjans L García D</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="151"/>
        <source> Italian translation</source>
        <translation> Olasz fordítás</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="155"/>
        <source>Testing:</source>
        <translation>Tesztelés:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="157"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>Két monitor támogatása és egyéb Linuxon</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support in Linux</source>
        <translation>Két monitor támogatása Linuxon</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>win32 kiadás [Windows XP és 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>régi win32 kiadás [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>win32-build [Windows 7]</source>
        <translation>win32 kiadás [Windows 7]</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="186"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>Könyvtár %1 nem létezik. Létre szeretné hozni?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="187"/>
        <location filename="../src/core/ui/configwidget.cpp" line="275"/>
        <source>Warning</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="263"/>
        <source>Select directory</source>
        <translation>Könyvtár kiválasztása</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="274"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Vissza szeretné állítani a beállításokat az alapértelmezett értékre?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="332"/>
        <source>Example: </source>
        <translation>Példa: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="377"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>Ezt a billentyűt már használja a ScreenGrab! Válasszon másikat.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="395"/>
        <source>This key is not supported on your system!</source>
        <translation>Ez a billentyű nem támogatott ezen a rendszeren!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="415"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="62"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>Egy többplatformos alkalmazás gyors képernyőképkészítésére az asztalról.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="66"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Képernyőkép készítése teljes képernyőről</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="70"/>
        <source>Take a screenshot of the active window</source>
        <translation>Képernyőkép készítése a legutóbbi aktív ablakról</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="74"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Képernyőkép készítése kijelölt területről</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="78"/>
        <source>Run the application with a hidden main window</source>
        <translation>Az alkalmazás futtatása rejtett főablakkal</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="455"/>
        <source>Saved</source>
        <translation>Mentve</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="455"/>
        <source>Saved to </source>
        <translation>Mentve ide: </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="477"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Mentett fájl neve a vágólapra másolva</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="483"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>Mentett fájl útvonala a vágólapra másolva</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="505"/>
        <source>Copied</source>
        <translation>Másolva</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="505"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>Képernyőkép a vágólapra másolva</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation>ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>Képernyőkép típusa</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>Ablak</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>Kijelölt terület</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation>Legutóbb kijelölt terület</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation>Késleltetés:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Késleltetés képernyőkép készítése előtt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> mp</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation>Terület nagyítása az egér körül</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation>Ne legyen benne az ablak fejléce</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation>Egérmutató is</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation>Eszköztár</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>New</source>
        <translation>Új képernyőkép</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
        <source>Quit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="341"/>
        <source>Screenshot </source>
        <translation>Képernyőkép </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="345"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Dupla kattintás képernyőkép megnyitásához külső képnézegetőben</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="354"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="485"/>
        <source>Hide</source>
        <translation>Elrejtés</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="492"/>
        <source>Show</source>
        <translation>Megjelenítés</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="545"/>
        <source>%1 Files</source>
        <translation>%1 fájl</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="567"/>
        <source>Save As...</source>
        <translation>Mentés másként...</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="175"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>Kattintson és húzza a terület kijelöléséhez,
kattintson jobb egérgombbal, hogy illeszkedjen a szélekhez,
kattintson duplán, vagy nyomja meg az Enter billentyűt
a befejezéshez.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="207"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 pixel </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Szerkesztés külső alkalmazással</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Megnyitás...</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>A Qt-ról</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="601"/>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>Alap</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>Haladó</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation>Rendszertálca</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation>Alapértelmezett mentési könyvtár</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation>Alapértelmezett mentési útvonal</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>Fájlrendszer böngészése</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>Böngészés</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation>Alapértelmezett fájl</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>Alapértelmezett fájlnév</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation>Formátum</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>Alapértelmezett képformátum</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Mentéskor fájl nevének vágólapra másolása</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation>Nincs másolás</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation>Fájl nevének másolása</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation>Fájl útvonalának másolása</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>Képminőség</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Képminőség (1 - kis fájl, 100 - jó minőség)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Aktuális dátum és idő a mentett fájlnévbe</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation>Aktuális dátum és idő a fájlnévbe</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>Sablon: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>Példa: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Képernyőképek automatikus mentése a húzás során</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>Képernyőkép automatikus mentése</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>Első képernyőkép mentése</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Több ablak engedélyezése</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Több ablak engedélyezése</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation>Megnyitás külső képnézegetőben dupla kattintásra</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>Megnyitás külső képnézegetőben</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>Ha ez nincs bejelölve, akkor a kijelölt terület
nagyobb lehet, hogy illeszkedjen a külső szélekhez</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="411"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>Jobb kattintásra a szélek igazítása a kijelölt területhez</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="449"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>ScreenGrab megjelenítése a rendszertálcán</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="458"/>
        <source>Tray messages:</source>
        <translation>Rendszertálca üzenetek:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="471"/>
        <source>Tray messages display mode</source>
        <translation>Rendszertálca üzenetek megjelenítési módja</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="475"/>
        <source>Never</source>
        <translation>Soha</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="480"/>
        <source>Tray mode</source>
        <translation>Rendszertálca mód</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="485"/>
        <source>Always</source>
        <translation>Mindig</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="497"/>
        <source>Time of display tray messages</source>
        <translation>Rendszertálca üzenetek megjelenítési ideje</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="513"/>
        <source>Time to display tray messages</source>
        <translation>Idő amíg látható a üzenet</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="516"/>
        <source> sec</source>
        <translation> mp</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="534"/>
        <source>Minimize to tray on click close button</source>
        <translation>Bezárás gombra kattintáskor minimalizálás a rendszertálcára</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="537"/>
        <source>Minimize to tray when closing</source>
        <translation>Bezáráskor minimalizálás a renszertálcára</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="576"/>
        <source>Action</source>
        <translation>Művelet</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="581"/>
        <source>Shortcut</source>
        <translation>Kombináció</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="586"/>
        <source>New screen</source>
        <translation>Új képernyőkép</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="591"/>
        <source>Save screen</source>
        <translation>Képernyőkép mentése</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="596"/>
        <source>Copy screen</source>
        <translation>Képernyőkép másolása</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="606"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="611"/>
        <source>Quit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="621"/>
        <source>Selected shortcut:</source>
        <translation>Kiválasztott gyorsbillentyű:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="628"/>
        <source>Not defined</source>
        <translation>Nincs meghatározva</translation>
    </message>
</context>
</TS>
